@@ -1,3 +1,23 @@
+/*
+    GNOME Commander - A GNOME based file manager
+    Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
+
+    This program is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
+*/
+
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
@@ -15,16 +35,14 @@
 #include "close.xpm"
 
 
-static GtkWidget*
-create_compare_win (LogHistory *log_history);
+static GtkWidget *create_compare_win (LogHistory *log_history);
 
 
-static void
-on_rev_list_select_row                 (GtkCList        *clist,
-                                        gint             row,
-                                        gint             column,
-                                        GdkEvent        *event,
-                                        LogHistory      *log_history)
+static void on_rev_list_select_row  (GtkCList *clist,
+                                     gint row,
+                                     gint column,
+                                     GdkEvent *event,
+                                     LogHistory *log_history)
 {
     Revision *rev = (Revision *)gtk_clist_get_row_data (clist, row);
 
@@ -36,7 +54,8 @@ on_rev_list_select_row                 (GtkCList        *clist,
 
     log_history->plugin->selected_rev = rev;
 
-    if (rev->message) {
+    if (rev->message)
+    {
         GtkTextBuffer *buf = gtk_text_buffer_new (NULL);
         gtk_text_buffer_set_text (buf, rev->message, strlen (rev->message));
         gtk_text_view_set_buffer (GTK_TEXT_VIEW (log_history->msg_text_view), buf);
@@ -44,28 +63,24 @@ on_rev_list_select_row                 (GtkCList        *clist,
 }
 
 
-static void
-on_compare_clicked                     (GtkButton       *button,
-                                        LogHistory      *log_history)
+static void on_compare_clicked (GtkButton *button, LogHistory *log_history)
 {
     GtkWidget *dlg = create_compare_win (log_history);
     GtkWidget *combo = lookup_widget (GTK_WIDGET (dlg), "rev_combo");
 
-    gtk_combo_set_popdown_strings (
-        GTK_COMBO (combo), log_history->rev_names);
+    gtk_combo_set_popdown_strings (GTK_COMBO (combo), log_history->rev_names);
     gtk_widget_show (dlg);
 }
 
 
-static void
-on_compare_ok (GtkButton *button, GtkWidget *dialog)
+static void on_compare_ok (GtkButton *button, GtkWidget *dialog)
 {
     gchar *cmd, *args, *prev_rev;
     const gchar *selected_rev, *selected_other_rev;
     GtkWidget *combo = lookup_widget (GTK_WIDGET (button), "rev_combo");
     GtkWidget *head_radio = lookup_widget (GTK_WIDGET (button), "head_radio");
     GtkWidget *prev_rev_radio = lookup_widget (GTK_WIDGET (button), "prev_rev_radio");
-    LogHistory *log_history = (LogHistory*)lookup_widget (GTK_WIDGET (button), "log_history");
+    LogHistory *log_history = (LogHistory *) lookup_widget (GTK_WIDGET (button), "log_history");
 
     selected_rev = gtk_object_get_data (GTK_OBJECT (dialog), "selected_rev");
     selected_other_rev = get_combo_text (combo);
@@ -94,20 +109,19 @@ on_compare_ok (GtkButton *button, GtkWidget *dialog)
 }
 
 
-static void
-on_compare_cancel (GtkButton *button, GtkWidget *dialog)
+static void on_compare_cancel (GtkButton *button, GtkWidget *dialog)
 {
     gtk_widget_destroy (dialog);
 }
 
 
-static void
-on_other_rev_toggled (GtkToggleButton *btn, GtkWidget *dialog)
+static void on_other_rev_toggled (GtkToggleButton *btn, GtkWidget *dialog)
 {
     GtkWidget *combo = lookup_widget (dialog, "rev_combo");
     GtkWidget *entry = GTK_COMBO (combo)->entry;
 
-    if (gtk_toggle_button_get_active (btn)) {
+    if (gtk_toggle_button_get_active (btn))
+    {
         gtk_widget_set_sensitive (combo, TRUE);
         gtk_widget_grab_focus (entry);
     }
@@ -116,23 +130,20 @@ on_other_rev_toggled (GtkToggleButton *btn, GtkWidget *dialog)
 }
 
 
-static Revision *
-find_prev_rev (LogHistory *h, Revision *rev)
+static Revision *find_prev_rev (LogHistory *h, Revision *rev)
 {
-    GList *l;
+    GList *l = g_list_find (h->revisions, rev);
 
-    l = g_list_find (h->revisions, rev);
-    if (!l) return NULL;
+    if (!l)
+        return NULL;
 
     l = l->next;
-    if (!l) return NULL;
 
-    return (Revision*)l->data;
+    return l ? (Revision *) l->data : NULL;
 }
 
 
-static GtkWidget*
-create_compare_win (LogHistory *log_history)
+static GtkWidget *create_compare_win (LogHistory *log_history)
 {
     GtkWidget *dialog;
     GtkWidget *vbox;
@@ -148,10 +159,8 @@ create_compare_win (LogHistory *log_history)
     if (prev_rev)
         gtk_object_set_data (GTK_OBJECT (dialog), "prev_rev", prev_rev->number);
 
-    gtk_object_set_data (GTK_OBJECT (dialog), "selected_rev",
-                         log_history->plugin->selected_rev->number);
-    gtk_object_set_data (GTK_OBJECT (dialog), "log_history",
-                         log_history);
+    gtk_object_set_data (GTK_OBJECT (dialog), "selected_rev", log_history->plugin->selected_rev->number);
+    gtk_object_set_data (GTK_OBJECT (dialog), "log_history", log_history);
 
 
     /**
@@ -161,65 +170,54 @@ create_compare_win (LogHistory *log_history)
     cat = create_category (dialog, vbox, _("Compare with"));
     gnome_cmd_dialog_add_category (GNOME_CMD_DIALOG (dialog), cat);
 
-    radio = create_radio (dialog, NULL, _("HEAD"),
-                          "head_radio");
+    radio = create_radio (dialog, NULL, _("HEAD"), "head_radio");
     gtk_box_pack_start (GTK_BOX (vbox), radio, TRUE, FALSE, 0);
 
-    radio = create_radio (dialog, get_radio_group(radio), _("The previous revision"),
-                          "prev_rev_radio");
+    radio = create_radio (dialog, get_radio_group(radio), _("The previous revision"), "prev_rev_radio");
     gtk_box_pack_start (GTK_BOX (vbox), radio, TRUE, FALSE, 0);
     if (!prev_rev)
         gtk_widget_set_sensitive (radio, FALSE);
 
-    radio = create_radio (dialog, get_radio_group(radio), _("Other revision"),
-                          "other_rev_radio");
+    radio = create_radio (dialog, get_radio_group(radio), _("Other revision"), "other_rev_radio");
     gtk_box_pack_start (GTK_BOX (vbox), radio, TRUE, FALSE, 0);
 
-    gtk_signal_connect (GTK_OBJECT (radio), "toggled",
-                        GTK_SIGNAL_FUNC (on_other_rev_toggled), dialog);
+    gtk_signal_connect (GTK_OBJECT (radio), "toggled", GTK_SIGNAL_FUNC (on_other_rev_toggled), dialog);
 
     combo = create_combo (dialog);
-    gtk_object_set_data_full (GTK_OBJECT (dialog), "rev_combo", combo,
-                              (GtkDestroyNotify) gtk_widget_unref);
+    gtk_object_set_data_full (GTK_OBJECT (dialog), "rev_combo", combo, (GtkDestroyNotify) gtk_widget_unref);
     gtk_box_pack_start (GTK_BOX (vbox), combo, TRUE, FALSE, 0);
     gtk_widget_set_sensitive (combo, FALSE);
 
-    gnome_cmd_dialog_add_button (
-        GNOME_CMD_DIALOG (dialog), GNOME_STOCK_BUTTON_CANCEL,
-        GTK_SIGNAL_FUNC (on_compare_cancel), dialog);
-    gnome_cmd_dialog_add_button (
-        GNOME_CMD_DIALOG (dialog), GNOME_STOCK_BUTTON_OK,
-        GTK_SIGNAL_FUNC (on_compare_ok), dialog);
+    gnome_cmd_dialog_add_button (GNOME_CMD_DIALOG (dialog), GTK_STOCK_CANCEL,
+                                 GTK_SIGNAL_FUNC (on_compare_cancel), dialog);
+    gnome_cmd_dialog_add_button (GNOME_CMD_DIALOG (dialog), GTK_STOCK_OK,
+                                 GTK_SIGNAL_FUNC (on_compare_ok), dialog);
 
     return dialog;
 }
 
 
-static void
-on_close_tab (GtkButton *button, GtkWidget *tab)
+static void on_close_tab (GtkButton *button, GtkWidget *tab)
 {
     gtk_widget_destroy (tab);
 }
 
 
-static void
-on_diff_window_close (GtkButton *button, CvsPlugin *plugin)
+static void on_diff_window_close (GtkButton *button, CvsPlugin *plugin)
 {
     gtk_widget_destroy (plugin->diff_win);
     plugin->diff_win = NULL;
 }
 
 
-static void
-on_log_window_close (GtkButton *button, CvsPlugin *plugin)
+static void on_log_window_close (GtkButton *button, CvsPlugin *plugin)
 {
     gtk_widget_destroy (plugin->log_win);
     plugin->log_win = NULL;
 }
 
 
-static gboolean
-on_log_win_delete (GtkWidget *widget, GdkEvent *event, CvsPlugin *plugin)
+static gboolean on_log_win_delete (GtkWidget *widget, GdkEvent *event, CvsPlugin *plugin)
 {
     gtk_widget_destroy (widget);
     plugin->log_win = NULL;
@@ -227,8 +225,7 @@ on_log_win_delete (GtkWidget *widget, GdkEvent *event, CvsPlugin *plugin)
 }
 
 
-static gboolean
-on_diff_win_delete (GtkWidget *widget, GdkEvent *event, CvsPlugin *plugin)
+static gboolean on_diff_win_delete (GtkWidget *widget, GdkEvent *event, CvsPlugin *plugin)
 {
     gtk_widget_destroy (widget);
     plugin->diff_win = NULL;
@@ -236,24 +233,21 @@ on_diff_win_delete (GtkWidget *widget, GdkEvent *event, CvsPlugin *plugin)
 }
 
 
-static gboolean
-on_log_win_destroy (GtkWidget *widget, GdkEvent *event, CvsPlugin *plugin)
+static gboolean on_log_win_destroy (GtkWidget *widget, GdkEvent *event, CvsPlugin *plugin)
 {
     plugin->log_win = NULL;
     return FALSE;
 }
 
 
-static gboolean
-on_diff_win_destroy (GtkWidget *widget, GdkEvent *event, CvsPlugin *plugin)
+static gboolean on_diff_win_destroy (GtkWidget *widget, GdkEvent *event, CvsPlugin *plugin)
 {
     plugin->diff_win = NULL;
     return FALSE;
 }
 
 
-GtkWidget *
-create_diff_win (CvsPlugin *plugin)
+GtkWidget *create_diff_win (CvsPlugin *plugin)
 {
     GtkWidget *dialog;
     GtkWidget *notebook;
@@ -264,21 +258,17 @@ create_diff_win (CvsPlugin *plugin)
     gtk_window_set_default_size (GTK_WINDOW (dialog), 510, 300);
 
     gnome_cmd_dialog_add_button (
-        GNOME_CMD_DIALOG (dialog), GNOME_STOCK_BUTTON_CLOSE,
+        GNOME_CMD_DIALOG (dialog), GTK_STOCK_CLOSE,
         GTK_SIGNAL_FUNC (on_diff_window_close), plugin);
 
-    gtk_signal_connect (GTK_OBJECT (dialog), "delete-event",
-                        GTK_SIGNAL_FUNC (on_diff_win_delete), plugin);
-    gtk_signal_connect (GTK_OBJECT (dialog), "destroy-event",
-                        GTK_SIGNAL_FUNC (on_diff_win_destroy), plugin);
+    gtk_signal_connect (GTK_OBJECT (dialog), "delete-event", GTK_SIGNAL_FUNC (on_diff_win_delete), plugin);
+    gtk_signal_connect (GTK_OBJECT (dialog), "destroy-event", GTK_SIGNAL_FUNC (on_diff_win_destroy), plugin);
 
     notebook = gtk_notebook_new ();
     gtk_widget_ref (notebook);
-    gtk_object_set_data_full (GTK_OBJECT (dialog), "notebook",
-                              notebook, (GtkDestroyNotify) gtk_widget_unref);
+    gtk_object_set_data_full (GTK_OBJECT (dialog), "notebook", notebook, (GtkDestroyNotify) gtk_widget_unref);
     gtk_widget_show (notebook);
-    gnome_cmd_dialog_add_expanding_category (
-        GNOME_CMD_DIALOG (dialog), notebook);
+    gnome_cmd_dialog_add_expanding_category (GNOME_CMD_DIALOG (dialog), notebook);
 
     gtk_widget_show (dialog);
 
@@ -286,8 +276,7 @@ create_diff_win (CvsPlugin *plugin)
 }
 
 
-GtkWidget*
-create_log_win (CvsPlugin *plugin)
+GtkWidget *create_log_win (CvsPlugin *plugin)
 {
     GtkWidget *dialog;
     GtkWidget *notebook;
@@ -299,7 +288,7 @@ create_log_win (CvsPlugin *plugin)
     gtk_window_set_policy (GTK_WINDOW (dialog), FALSE, TRUE, FALSE);
 
     gnome_cmd_dialog_add_button (
-        GNOME_CMD_DIALOG (dialog), GNOME_STOCK_BUTTON_CLOSE,
+        GNOME_CMD_DIALOG (dialog), GTK_STOCK_CLOSE,
         GTK_SIGNAL_FUNC (on_log_window_close), plugin);
 
     gtk_signal_connect (GTK_OBJECT (dialog), "delete-event",
@@ -309,11 +298,9 @@ create_log_win (CvsPlugin *plugin)
 
     notebook = gtk_notebook_new ();
     gtk_widget_ref (notebook);
-    gtk_object_set_data_full (GTK_OBJECT (dialog), "notebook",
-                              notebook, (GtkDestroyNotify) gtk_widget_unref);
+    gtk_object_set_data_full (GTK_OBJECT (dialog), "notebook", notebook, (GtkDestroyNotify) gtk_widget_unref);
     gtk_widget_show (notebook);
-    gnome_cmd_dialog_add_expanding_category (
-        GNOME_CMD_DIALOG (dialog), notebook);
+    gnome_cmd_dialog_add_expanding_category (GNOME_CMD_DIALOG (dialog), notebook);
 
     gtk_widget_show (dialog);
 
@@ -353,8 +340,7 @@ static GtkWidget *create_tab_label (GtkWidget *parent,
 }
 
 
-void
-add_diff_tab (CvsPlugin *plugin, const gchar *cmd, const gchar *fname)
+void add_diff_tab (CvsPlugin *plugin, const gchar *cmd, const gchar *fname)
 {
     gint ret;
     FILE *fd;
@@ -366,14 +352,12 @@ add_diff_tab (CvsPlugin *plugin, const gchar *cmd, const gchar *fname)
     GtkWidget *notebook;
 
     sw = create_sw (plugin->diff_win);
-    gtk_scrolled_window_set_shadow_type (
-        GTK_SCROLLED_WINDOW (sw), GTK_SHADOW_IN);
+    gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw), GTK_SHADOW_IN);
 
     text_view = gtk_text_view_new ();
     gtk_container_add (GTK_CONTAINER (sw), text_view);
     gtk_widget_ref (text_view);
-    gtk_object_set_data_full (GTK_OBJECT (sw), "text_view", text_view,
-                              (GtkDestroyNotify) gtk_widget_unref);
+    gtk_object_set_data_full (GTK_OBJECT (sw), "text_view", text_view, (GtkDestroyNotify) gtk_widget_unref);
     gtk_widget_show (text_view);
 
     notebook = lookup_widget (plugin->diff_win, "notebook");
@@ -383,19 +367,21 @@ add_diff_tab (CvsPlugin *plugin, const gchar *cmd, const gchar *fname)
 
 
     fd = popen (cmd, "r");
-    if (fd < 0) return;
-    do {
+    if (fd==0) return;
+
+    do
+    {
         ret = fread (buf, 1, 256, fd);
         gtk_text_buffer_insert_at_cursor (text_buffer, buf, ret);
-    } while (ret == 256);
+    }
+    while (ret == 256);
 
     gtk_text_view_set_buffer (GTK_TEXT_VIEW (text_view), text_buffer);
     pclose (fd);
 }
 
 
-void
-add_log_tab (CvsPlugin *plugin, const gchar *fname)
+void add_log_tab (CvsPlugin *plugin, const gchar *fname)
 {
     GList *revs;
     GtkWidget *hpaned;
@@ -545,8 +531,8 @@ add_log_tab (CvsPlugin *plugin, const gchar *fname)
     tab_label = create_tab_label (notebook, fname, GTK_SIGNAL_FUNC (on_close_tab), hpaned);
     gtk_notebook_append_page (GTK_NOTEBOOK (notebook), hpaned, tab_label);
 
-    revs = log_history->revisions;
-    while (revs) {
+    for (revs = log_history->revisions; revs; revs = revs->next)
+    {
         Revision *rev = (Revision *)revs->data;
         gint row;
         gchar *text[2];
@@ -555,11 +541,9 @@ add_log_tab (CvsPlugin *plugin, const gchar *fname)
         // Add this rev. to the list
         row = gtk_clist_append (GTK_CLIST (rev_list), text);
         gtk_clist_set_row_data (GTK_CLIST (rev_list), row, rev);
-        revs = revs->next;
     }
 
-    gtk_signal_connect (GTK_OBJECT (rev_list), "select_row",
-                        GTK_SIGNAL_FUNC (on_rev_list_select_row), log_history);
+    gtk_signal_connect (GTK_OBJECT (rev_list), "select-row", GTK_SIGNAL_FUNC (on_rev_list_select_row), log_history);
 
     gtk_clist_select_row (GTK_CLIST (rev_list), 0, 0);
 }
