@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,8 +20,6 @@
 #ifndef __GNOME_CMD_CLIST_H__
 #define __GNOME_CMD_CLIST_H__
 
-G_BEGIN_DECLS
-
 #define GNOME_CMD_CLIST(obj) \
     GTK_CHECK_CAST (obj, gnome_cmd_clist_get_type (), GnomeCmdCList)
 #define GNOME_CMD_CLIST_CLASS(klass) \
@@ -29,12 +28,10 @@ G_BEGIN_DECLS
     GTK_CHECK_TYPE (obj, gnome_cmd_clist_get_type ())
 
 
-typedef struct _GnomeCmdCList GnomeCmdCList;
-typedef struct _GnomeCmdCListPrivate GnomeCmdCListPrivate;
-typedef struct _GnomeCmdCListClass GnomeCmdCListClass;
+struct GnomeCmdCListPrivate;
 
 
-struct _GnomeCmdCList
+struct GnomeCmdCList
 {
     GtkCList parent;
 
@@ -44,37 +41,28 @@ struct _GnomeCmdCList
 };
 
 
-struct _GnomeCmdCListClass
+struct GnomeCmdCListClass
 {
     GtkCListClass parent_class;
 };
 
 
 
-GtkType
-gnome_cmd_clist_get_type            (void);
+GtkType gnome_cmd_clist_get_type ();
 
-GtkWidget*
-gnome_cmd_clist_new                 (gint columns);
+GtkWidget *gnome_cmd_clist_new_with_titles (gint columns, gchar **titles);
 
-GtkWidget*
-gnome_cmd_clist_new_with_titles     (gint columns, gchar **titles);
+inline GtkWidget *gnome_cmd_clist_new (gint columns)
+{
+    return gnome_cmd_clist_new_with_titles (columns, NULL);
+}
 
-void
-gnome_cmd_clist_update_style        (GnomeCmdCList *clist);
+void gnome_cmd_clist_update_style        (GnomeCmdCList *clist);
 
-gint
-gnome_cmd_clist_get_voffset         (GnomeCmdCList *clist);
+gint gnome_cmd_clist_get_voffset (GnomeCmdCList *clist);
+void gnome_cmd_clist_set_voffset (GnomeCmdCList *clist, gint voffset);
 
-void
-gnome_cmd_clist_set_voffset         (GnomeCmdCList *clist, gint voffset);
-
-gint
-gnome_cmd_clist_get_row             (GnomeCmdCList *clist, gint x, gint y);
-
-void
-gnome_cmd_clist_set_drag_row        (GnomeCmdCList *clist, gint row);
-
-G_END_DECLS
+gint gnome_cmd_clist_get_row (GnomeCmdCList *clist, gint x, gint y);
+void gnome_cmd_clist_set_drag_row (GnomeCmdCList *clist, gint row);
 
 #endif // __GNOME_CMD_CLIST_H__
