@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -18,6 +19,7 @@
 */
 
 #include <config.h>
+
 #include "gnome-cmd-includes.h"
 #include "gnome-cmd-data.h"
 #include "gnome-cmd-con-ftp.h"
@@ -96,7 +98,7 @@ static gboolean ftp_close (GnomeCmdCon *con)
 {
     gnome_cmd_con_set_default_dir (con, NULL);
     gnome_cmd_con_set_cwd (con, NULL);
-    gtk_object_unref (GTK_OBJECT (con->base_path));
+    g_object_unref (con->base_path);
     con->base_path = NULL;
     con->state = CON_STATE_CLOSED;
     con->open_result = CON_OPEN_NOT_STARTED;
@@ -170,7 +172,7 @@ static void class_init (GnomeCmdConFtpClass *klass)
 
 static void init (GnomeCmdConFtp *ftp_con)
 {
-    guint dev_icon_size = gnome_cmd_data_get_dev_icon_size ();
+    guint dev_icon_size = gnome_cmd_data.dev_icon_size;
     gint icon_size;
 
     g_assert (gtk_icon_size_lookup (GTK_ICON_SIZE_LARGE_TOOLBAR, &icon_size, NULL));
@@ -217,7 +219,7 @@ static void init (GnomeCmdConFtp *ftp_con)
  * Public functions
  ***********************************/
 
-GtkType gnome_cmd_con_ftp_get_type (void)
+GtkType gnome_cmd_con_ftp_get_type ()
 {
     static GtkType type = 0;
 
