@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -18,6 +19,7 @@
 */
 
 #include <config.h>
+
 #include "gnome-cmd-includes.h"
 #include "gnome-cmd-dir-indicator.h"
 #include "gnome-cmd-style.h"
@@ -31,7 +33,7 @@
 using namespace std;
 
 
-struct _GnomeCmdDirIndicatorPrivate
+struct GnomeCmdDirIndicatorPrivate
 {
     GtkWidget *event_box;
     GtkWidget *label;
@@ -54,8 +56,7 @@ static GtkFrameClass *parent_class = NULL;
 /*******************************
  * Gtk class implementation
  *******************************/
-static void
-destroy (GtkObject *object)
+static void destroy (GtkObject *object)
 {
     GnomeCmdDirIndicator *dir_indicator = GNOME_CMD_DIR_INDICATOR (object);
 
@@ -68,8 +69,7 @@ destroy (GtkObject *object)
 }
 
 
-static void
-class_init (GnomeCmdDirIndicatorClass *klass)
+static void class_init (GnomeCmdDirIndicatorClass *klass)
 {
     GtkObjectClass *object_class = GTK_OBJECT_CLASS (klass);
     GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
@@ -83,10 +83,7 @@ class_init (GnomeCmdDirIndicatorClass *klass)
 /*******************************
  * Event handlers
  *******************************/
-static gboolean
-on_dir_indicator_clicked (GnomeCmdDirIndicator *indicator,
-                          GdkEventButton *event,
-                          GnomeCmdFileSelector *fs)
+static gboolean on_dir_indicator_clicked (GnomeCmdDirIndicator *indicator, GdkEventButton *event, GnomeCmdFileSelector *fs)
 {
     g_return_val_if_fail (GNOME_CMD_IS_DIR_INDICATOR (indicator), FALSE);
 
@@ -96,15 +93,14 @@ on_dir_indicator_clicked (GnomeCmdDirIndicator *indicator,
         const gchar *labelText = gtk_label_get_text (GTK_LABEL (indicator->priv->label));
         gchar *chTo = g_strdup(labelText);
         gint x = (gint) event->x;
-        gint i;
 
-        for (i = 0; i < indicator->priv->numPositions; i++)
+        for (gint i = 0; i < indicator->priv->numPositions; i++)
             if (x < indicator->priv->slashPixelPosition[i])
             {
                 strncpy (chTo, labelText, indicator->priv->slashCharPosition[i]);
                 chTo[indicator->priv->slashCharPosition[i]] = 0x0;
                 gnome_cmd_main_win_switch_fs (main_win, fs);
-                gnome_cmd_file_selector_goto_directory (fs, chTo);
+                fs->goto_directory(chTo);
                 g_free (chTo);
                 return TRUE;
             }
@@ -117,14 +113,13 @@ on_dir_indicator_clicked (GnomeCmdDirIndicator *indicator,
 }
 
 
-static void
-update_markup (GnomeCmdDirIndicator *indicator, gint i)
+inline void update_markup (GnomeCmdDirIndicator *indicator, gint i)
 {
-    gchar *s, *m;
-
     if (!indicator->priv->slashCharPosition)
         return;
 
+    gchar *s, *m;
+
     s = g_strdup (gtk_label_get_text (GTK_LABEL (indicator->priv->label)));
 
     if (i >= 0)
@@ -148,10 +143,7 @@ update_markup (GnomeCmdDirIndicator *indicator, gint i)
 }
 
 
-static gint
-on_dir_indicator_motion (GnomeCmdDirIndicator *indicator,
-                         GdkEventMotion *event,
-                         gpointer user_data)
+static gint on_dir_indicator_motion (GnomeCmdDirIndicator *indicator, GdkEventMotion *event, gpointer user_data)
 {
     gint i, iX, iY;
 
@@ -189,10 +181,7 @@ on_dir_indicator_motion (GnomeCmdDirIndicator *indicator,
 }
 
 
-static gint
-on_dir_indicator_leave (GnomeCmdDirIndicator *indicator,
-                        GdkEventMotion *event,
-                        gpointer user_data)
+static gint on_dir_indicator_leave (GnomeCmdDirIndicator *indicator, GdkEventMotion *event, gpointer user_data)
 {
     g_return_val_if_fail (GNOME_CMD_IS_DIR_INDICATOR (indicator), FALSE);
 
@@ -204,8 +193,7 @@ on_dir_indicator_leave (GnomeCmdDirIndicator *indicator,
 }
 
 
-static int
-get_string_pixel_size (const char *s, int len)
+inline int get_string_pixel_size (const char *s, int len)
 {
     // find the size, in pixels, of the given string
     gint xSize, ySize;
@@ -231,8 +219,7 @@ get_string_pixel_size (const char *s, int len)
 }
 
 
-static gboolean
-on_bookmark_button_clicked (GtkWidget *button, GnomeCmdDirIndicator *indicator)
+static gboolean on_bookmark_button_clicked (GtkWidget *button, GnomeCmdDirIndicator *indicator)
 {
     if (indicator->priv->bookmark_is_popped)
     {
@@ -249,8 +236,7 @@ on_bookmark_button_clicked (GtkWidget *button, GnomeCmdDirIndicator *indicator)
 }
 
 
-static gboolean
-on_history_button_clicked (GtkWidget *button, GnomeCmdDirIndicator *indicator)
+static gboolean on_history_button_clicked (GtkWidget *button, GnomeCmdDirIndicator *indicator)
 {
     if (indicator->priv->history_is_popped)
     {
@@ -267,24 +253,21 @@ on_history_button_clicked (GtkWidget *button, GnomeCmdDirIndicator *indicator)
 }
 
 
-static void
-on_dir_history_popup_hide (GtkMenu *menu, GnomeCmdDirIndicator *indicator)
+static void on_dir_history_popup_hide (GtkMenu *menu, GnomeCmdDirIndicator *indicator)
 {
     indicator->priv->dir_history_popup = NULL;
     indicator->priv->history_is_popped = FALSE;
 }
 
 
-static void
-on_bookmark_popup_hide (GtkMenu *menu, GnomeCmdDirIndicator *indicator)
+static void on_bookmark_popup_hide (GtkMenu *menu, GnomeCmdDirIndicator *indicator)
 {
     indicator->priv->bookmark_popup = NULL;
     indicator->priv->bookmark_is_popped = FALSE;
 }
 
 
-static void
-on_dir_history_item_selected (GtkMenuItem *item, const gchar *path)
+static void on_dir_history_item_selected (GtkMenuItem *item, const gchar *path)
 {
     g_return_if_fail (path != NULL);
 
@@ -293,12 +276,11 @@ on_dir_history_item_selected (GtkMenuItem *item, const gchar *path)
     g_return_if_fail (GNOME_CMD_IS_DIR_INDICATOR (indicator));
 
     gnome_cmd_main_win_switch_fs (main_win, indicator->priv->fs);
-    gnome_cmd_file_selector_goto_directory (indicator->priv->fs, path);
+    indicator->priv->fs->goto_directory(path);
 }
 
 
-static void
-on_bookmark_item_selected (GtkMenuItem *item, GnomeCmdBookmark *bm)
+static void on_bookmark_item_selected (GtkMenuItem *item, GnomeCmdBookmark *bm)
 {
     g_return_if_fail (bm != NULL);
 
@@ -307,26 +289,21 @@ on_bookmark_item_selected (GtkMenuItem *item, GnomeCmdBookmark *bm)
     g_return_if_fail (GNOME_CMD_IS_DIR_INDICATOR (indicator));
 
     gnome_cmd_main_win_switch_fs (main_win, indicator->priv->fs);
-    gnome_cmd_file_selector_goto_directory (indicator->priv->fs, bm->path);
+    indicator->priv->fs->goto_directory(bm->path);
 }
 
 
-static void
-get_popup_pos (GtkMenu *menu,
-               gint *x, gint *y, gboolean push_in,
-               GnomeCmdDirIndicator *indicator)
+static void get_popup_pos (GtkMenu *menu, gint *x, gint *y, gboolean push_in, GnomeCmdDirIndicator *indicator)
 {
     g_return_if_fail (GNOME_CMD_IS_DIR_INDICATOR (indicator));
 
-    GtkWidget *w = GTK_WIDGET (indicator->priv->fs->list);
+    GtkWidget *w = GTK_WIDGET (indicator->priv->fs->file_list());
 
     gdk_window_get_origin (w->window, x, y);
 }
 
 
-static void
-add_menu_item (GnomeCmdDirIndicator *indicator, GtkMenuShell *shell, const gchar *text,
-               GtkSignalFunc func, gpointer data)
+static void add_menu_item (GnomeCmdDirIndicator *indicator, GtkMenuShell *shell, const gchar *text, GtkSignalFunc func, gpointer data)
 {
     GtkWidget *item = text ? gtk_menu_item_new_with_label (text) : gtk_menu_item_new ();
 
@@ -342,14 +319,8 @@ add_menu_item (GnomeCmdDirIndicator *indicator, GtkMenuShell *shell, const gchar
 }
 
 
-static void
-popup_dir_history (GnomeCmdDirIndicator *indicator)
+static void popup_dir_history (GnomeCmdDirIndicator *indicator)
 {
-    GList *l;
-    GnomeCmdCon *con;
-    History *history;
-    gint w = -1;
-
     if (indicator->priv->dir_history_popup) return;
 
     indicator->priv->dir_history_popup = gtk_menu_new ();
@@ -361,21 +332,22 @@ popup_dir_history (GnomeCmdDirIndicator *indicator)
         GTK_OBJECT (indicator->priv->dir_history_popup), "hide",
         GTK_SIGNAL_FUNC (on_dir_history_popup_hide), indicator);
 
-    con = gnome_cmd_file_selector_get_connection (indicator->priv->fs);
-    history = gnome_cmd_con_get_dir_history (con);
+    GnomeCmdCon *con = indicator->priv->fs->get_connection();
+    History *history = gnome_cmd_con_get_dir_history (con);
 
-    for (l=history->ents; l; l=l->next)
+    for (GList *l=history->ents; l; l=l->next)
     {
         gchar *path = (gchar *) l->data;
-        add_menu_item (
-            indicator,
-            GTK_MENU_SHELL (indicator->priv->dir_history_popup),
-            path,
-            GTK_SIGNAL_FUNC (on_dir_history_item_selected),
-            path);
+        add_menu_item (indicator,
+                       GTK_MENU_SHELL (indicator->priv->dir_history_popup),
+                       path,
+                       GTK_SIGNAL_FUNC (on_dir_history_item_selected),
+                       path);
     }
 
-    gnome_popup_menu_do_popup (indicator->priv->dir_history_popup, (GtkMenuPositionFunc)get_popup_pos, indicator, NULL, NULL, NULL);
+    gnome_popup_menu_do_popup (indicator->priv->dir_history_popup, (GtkMenuPositionFunc) get_popup_pos, indicator, NULL, NULL, NULL);
+
+    gint w = -1;
 
     if (GTK_WIDGET (indicator)->allocation.width > 100)
         w = GTK_WIDGET (indicator)->allocation.width;
@@ -384,38 +356,30 @@ popup_dir_history (GnomeCmdDirIndicator *indicator)
 }
 
 
-static void
-on_bookmarks_add_current (GtkMenuItem *item, GnomeCmdDirIndicator *indicator)
+static void on_bookmarks_add_current (GtkMenuItem *item, GnomeCmdDirIndicator *indicator)
 {
-    GnomeCmdDir *dir = gnome_cmd_file_selector_get_directory (indicator->priv->fs);
-    GnomeCmdCon *con = gnome_cmd_file_selector_get_connection (indicator->priv->fs);
+    GnomeCmdFile *f = GNOME_CMD_FILE (indicator->priv->fs->get_directory());
+    GnomeCmdCon *con = indicator->priv->fs->get_connection();
     GnomeCmdBookmarkGroup *group = gnome_cmd_con_get_bookmarks (con);
 
     GnomeCmdBookmark *bm = g_new0 (GnomeCmdBookmark, 1);
 
-    bm->name = g_strdup (gnome_cmd_file_get_name (GNOME_CMD_FILE (dir)));
-    bm->path = gnome_cmd_file_get_path (GNOME_CMD_FILE (dir));
+    bm->name = g_strdup (gnome_cmd_file_get_name (f));
+    bm->path = gnome_cmd_file_get_path (f);
     bm->group = group;
 
     group->bookmarks = g_list_append (group->bookmarks, bm);
 }
 
 
-static void
-on_bookmarks_manage (GtkMenuItem *item, GnomeCmdDirIndicator *indicator)
+static void on_bookmarks_manage (GtkMenuItem *item, GnomeCmdDirIndicator *indicator)
 {
     bookmarks_edit (NULL, NULL);
 }
 
 
-static void
-popup_bookmarks (GnomeCmdDirIndicator *indicator)
+inline void popup_bookmarks (GnomeCmdDirIndicator *indicator)
 {
-    GList *l;
-    GnomeCmdCon *con;
-    GnomeCmdBookmarkGroup *group;
-    gint w = -1;
-
     if (indicator->priv->bookmark_popup) return;
 
     indicator->priv->bookmark_popup = gtk_menu_new ();
@@ -423,25 +387,26 @@ popup_bookmarks (GnomeCmdDirIndicator *indicator)
     gtk_object_set_data_full (GTK_OBJECT (indicator), "bookmark_popup", indicator->priv->bookmark_popup, (GtkDestroyNotify) gtk_widget_unref);
     gtk_signal_connect (GTK_OBJECT (indicator->priv->bookmark_popup), "hide", GTK_SIGNAL_FUNC (on_bookmark_popup_hide), indicator);
 
-    con = gnome_cmd_file_selector_get_connection (indicator->priv->fs);
-    group = gnome_cmd_con_get_bookmarks (con);
+    GnomeCmdCon *con = indicator->priv->fs->get_connection();
+    GnomeCmdBookmarkGroup *group = gnome_cmd_con_get_bookmarks (con);
 
-    for (l = group->bookmarks; l; l = l->next)
+    for (GList *l = group->bookmarks; l; l = l->next)
     {
         GnomeCmdBookmark *bm = (GnomeCmdBookmark *) l->data;
-        add_menu_item (
-            indicator,
-            GTK_MENU_SHELL (indicator->priv->bookmark_popup),
-            bm->name,
-            GTK_SIGNAL_FUNC (on_bookmark_item_selected),
-            bm);
+        add_menu_item (indicator,
+                       GTK_MENU_SHELL (indicator->priv->bookmark_popup),
+                       bm->name,
+                       GTK_SIGNAL_FUNC (on_bookmark_item_selected),
+                       bm);
     }
 
     add_menu_item (indicator, GTK_MENU_SHELL (indicator->priv->bookmark_popup), NULL, NULL, indicator);
     add_menu_item (indicator, GTK_MENU_SHELL (indicator->priv->bookmark_popup), _("Add current dir"), GTK_SIGNAL_FUNC (on_bookmarks_add_current), indicator);
     add_menu_item (indicator, GTK_MENU_SHELL (indicator->priv->bookmark_popup), _("Manage bookmarks..."), GTK_SIGNAL_FUNC (on_bookmarks_manage), indicator);
 
-    gnome_popup_menu_do_popup (indicator->priv->bookmark_popup, (GtkMenuPositionFunc)get_popup_pos, indicator, NULL, NULL, NULL);
+    gnome_popup_menu_do_popup (indicator->priv->bookmark_popup, (GtkMenuPositionFunc) get_popup_pos, indicator, NULL, NULL, NULL);
+
+    gint w = -1;
 
     if (GTK_WIDGET (indicator)->allocation.width > 100)
         w = GTK_WIDGET (indicator)->allocation.width;
@@ -450,8 +415,7 @@ popup_bookmarks (GnomeCmdDirIndicator *indicator)
 }
 
 
-static void
-init (GnomeCmdDirIndicator *indicator)
+static void init (GnomeCmdDirIndicator *indicator)
 {
     GtkWidget *hbox, *arrow, *bbox;
 
@@ -467,9 +431,9 @@ init (GnomeCmdDirIndicator *indicator)
     // create the directory label and its event box
     indicator->priv->event_box = gtk_event_box_new ();
     gtk_widget_ref (indicator->priv->event_box);
-    gtk_signal_connect_object (GTK_OBJECT (indicator->priv->event_box), "motion_notify_event",
+    gtk_signal_connect_object (GTK_OBJECT (indicator->priv->event_box), "motion-notify-event",
                                GTK_SIGNAL_FUNC (on_dir_indicator_motion), indicator);
-    gtk_signal_connect_object (GTK_OBJECT (indicator->priv->event_box), "leave_notify_event",
+    gtk_signal_connect_object (GTK_OBJECT (indicator->priv->event_box), "leave-notify-event",
                                GTK_SIGNAL_FUNC (on_dir_indicator_leave), indicator);
     gtk_widget_set_events (indicator->priv->event_box, GDK_POINTER_MOTION_MASK);
 
@@ -482,7 +446,7 @@ init (GnomeCmdDirIndicator *indicator)
     indicator->priv->history_button = gtk_button_new ();
     GTK_WIDGET_UNSET_FLAGS (indicator->priv->history_button, GTK_CAN_FOCUS);
     gtk_widget_ref (indicator->priv->history_button);
-    gtk_button_set_relief (GTK_BUTTON (indicator->priv->history_button), gnome_cmd_data_get_button_relief ());
+    gtk_button_set_relief (GTK_BUTTON (indicator->priv->history_button), gnome_cmd_data.button_relief);
     gtk_object_set_data_full (GTK_OBJECT (indicator),
                               "button", indicator->priv->history_button,
                               (GtkDestroyNotify) gtk_widget_unref);
@@ -497,7 +461,7 @@ init (GnomeCmdDirIndicator *indicator)
     // create the bookmark popup button
     indicator->priv->bookmark_button = create_styled_pixmap_button (NULL, IMAGE_get_gnome_cmd_pixmap (PIXMAP_BOOKMARK));
     GTK_WIDGET_UNSET_FLAGS (indicator->priv->bookmark_button, GTK_CAN_FOCUS);
-    gtk_button_set_relief (GTK_BUTTON (indicator->priv->bookmark_button), gnome_cmd_data_get_button_relief ());
+    gtk_button_set_relief (GTK_BUTTON (indicator->priv->bookmark_button), gnome_cmd_data.button_relief);
     gtk_object_set_data_full (GTK_OBJECT (indicator), "button", indicator->priv->bookmark_button, (GtkDestroyNotify) gtk_widget_unref);
     gtk_widget_show (indicator->priv->bookmark_button);
 
@@ -518,8 +482,7 @@ init (GnomeCmdDirIndicator *indicator)
 /***********************************
  * Public functions
  ***********************************/
-GtkType
-gnome_cmd_dir_indicator_get_type    (void)
+GtkType gnome_cmd_dir_indicator_get_type ()
 {
     static GtkType type = 0;
 
@@ -543,12 +506,11 @@ gnome_cmd_dir_indicator_get_type    (void)
 }
 
 
-GtkWidget *
-gnome_cmd_dir_indicator_new (GnomeCmdFileSelector *fs)
+GtkWidget *gnome_cmd_dir_indicator_new (GnomeCmdFileSelector *fs)
 {
     GnomeCmdDirIndicator *dir_indicator = (GnomeCmdDirIndicator *) gtk_type_new (gnome_cmd_dir_indicator_get_type ());
 
-    gtk_signal_connect (GTK_OBJECT (dir_indicator), "button_press_event", G_CALLBACK (on_dir_indicator_clicked), fs);
+    gtk_signal_connect (GTK_OBJECT (dir_indicator), "button-press-event", G_CALLBACK (on_dir_indicator_clicked), fs);
 
     dir_indicator->priv->fs = fs;
 
@@ -556,8 +518,7 @@ gnome_cmd_dir_indicator_new (GnomeCmdFileSelector *fs)
 }
 
 
-void
-gnome_cmd_dir_indicator_set_dir (GnomeCmdDirIndicator *indicator, gchar *path)
+void gnome_cmd_dir_indicator_set_dir (GnomeCmdDirIndicator *indicator, gchar *path)
 {
     gchar *s = get_utf8 (path);
     gtk_label_set_text (GTK_LABEL (indicator->priv->label), s);
@@ -573,7 +534,7 @@ gnome_cmd_dir_indicator_set_dir (GnomeCmdDirIndicator *indicator, gchar *path)
     if (!path)
         return;
 
-    gboolean isUNC = g_str_has_prefix(path,"\\\\");
+    gboolean isUNC = g_str_has_prefix (path, "\\\\");
 
     if (!isUNC && *path!=G_DIR_SEPARATOR)
         return;
@@ -633,22 +594,19 @@ gnome_cmd_dir_indicator_set_dir (GnomeCmdDirIndicator *indicator, gchar *path)
 }
 
 
-void
-gnome_cmd_dir_indicator_set_active (GnomeCmdDirIndicator *indicator, gboolean value)
+void gnome_cmd_dir_indicator_set_active (GnomeCmdDirIndicator *indicator, gboolean value)
 {
     // FIXME: Do something creative here
 }
 
 
-void
-gnome_cmd_dir_indicator_show_history (GnomeCmdDirIndicator *indicator)
+void gnome_cmd_dir_indicator_show_history (GnomeCmdDirIndicator *indicator)
 {
     popup_dir_history (indicator);
 }
 
 
-void
-gnome_cmd_dir_indicator_show_bookmarks (GnomeCmdDirIndicator *indicator)
+void gnome_cmd_dir_indicator_show_bookmarks (GnomeCmdDirIndicator *indicator)
 {
     popup_bookmarks (indicator);
 }
