@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -24,8 +25,6 @@
 #include "gnome-cmd-con-device.h"
 #include "gnome-cmd-file-selector.h"
 
-G_BEGIN_DECLS
-
 #define GNOME_CMD_DIR_INDICATOR(obj) \
     GTK_CHECK_CAST (obj, gnome_cmd_dir_indicator_get_type (), GnomeCmdDirIndicator)
 #define GNOME_CMD_DIR_INDICATOR_CLASS(klass) \
@@ -34,42 +33,32 @@ G_BEGIN_DECLS
     GTK_CHECK_TYPE (obj, gnome_cmd_dir_indicator_get_type ())
 
 
-typedef struct _GnomeCmdDirIndicator GnomeCmdDirIndicator;
-typedef struct _GnomeCmdDirIndicatorClass GnomeCmdDirIndicatorClass;
-typedef struct _GnomeCmdDirIndicatorPrivate GnomeCmdDirIndicatorPrivate;
+struct GnomeCmdDirIndicatorPrivate;
 
 
-struct _GnomeCmdDirIndicator
+struct GnomeCmdDirIndicator
 {
     GtkFrame parent;
 
     GnomeCmdDirIndicatorPrivate *priv;
 };
 
-struct _GnomeCmdDirIndicatorClass
+struct GnomeCmdDirIndicatorClass
 {
     GtkFrameClass parent_class;
 };
 
 
-GtkType
-gnome_cmd_dir_indicator_get_type (void);
+GtkType gnome_cmd_dir_indicator_get_type ();
 
-GtkWidget *
-gnome_cmd_dir_indicator_new (GnomeCmdFileSelector *fs);
+GtkWidget *gnome_cmd_dir_indicator_new (GnomeCmdFileSelector *fs);
 
-void
-gnome_cmd_dir_indicator_set_dir (GnomeCmdDirIndicator *indicator, const gchar *path);
+void gnome_cmd_dir_indicator_set_dir (GnomeCmdDirIndicator *indicator, gchar *path);
 
-void
-gnome_cmd_dir_indicator_set_active (GnomeCmdDirIndicator *indicator, gboolean value);
+void gnome_cmd_dir_indicator_set_active (GnomeCmdDirIndicator *indicator, gboolean value);
 
-void
-gnome_cmd_dir_indicator_show_history (GnomeCmdDirIndicator *indicator);
+void gnome_cmd_dir_indicator_show_history (GnomeCmdDirIndicator *indicator);
 
-void
-gnome_cmd_dir_indicator_show_bookmarks (GnomeCmdDirIndicator *indicator);
-
-G_END_DECLS
+void gnome_cmd_dir_indicator_show_bookmarks (GnomeCmdDirIndicator *indicator);
 
 #endif // __GNOME_CMD_DIR_INDICATOR_H__
