@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,26 +21,34 @@
 #ifndef __GNOME_CMD_PIXMAP_H__
 #define __GNOME_CMD_PIXMAP_H__
 
-G_BEGIN_DECLS
-
-typedef struct {
+struct GnomeCmdPixmap
+{
     GdkPixbuf *pixbuf;
     GdkPixmap *pixmap;
     GdkBitmap *mask;
     gint width;
     gint height;
-} GnomeCmdPixmap;
+};
 
 
-GnomeCmdPixmap *
-gnome_cmd_pixmap_new_from_file (const gchar *filename);
+GnomeCmdPixmap *gnome_cmd_pixmap_new_from_file (const gchar *filepath, int width=-1, int height=-1);
+GnomeCmdPixmap *gnome_cmd_pixmap_new_from_icon (const gchar *icon_name, gint size, GtkIconLookupFlags flags=(GtkIconLookupFlags) 0);
+GnomeCmdPixmap *gnome_cmd_pixmap_new_from_pixbuf (GdkPixbuf *pixbuf);
 
-GnomeCmdPixmap *
-gnome_cmd_pixmap_new_from_pixbuf (GdkPixbuf *pixbuf);
+inline void gnome_cmd_pixmap_free (GnomeCmdPixmap *pixmap)
+{
+    if (!pixmap)
+        return;
 
-void
-gnome_cmd_pixmap_free (GnomeCmdPixmap *pixmap);
+    g_return_if_fail (pixmap->pixbuf != NULL);
+    g_return_if_fail (pixmap->pixmap != NULL);
+    g_return_if_fail (pixmap->mask != NULL);
 
-G_END_DECLS
+    gdk_pixbuf_unref (pixmap->pixbuf);
+    gdk_pixmap_unref (pixmap->pixmap);
+    gdk_bitmap_unref (pixmap->mask);
+
+    g_free (pixmap);
+}
 
 #endif // __GNOME_CMD_PIXMAP_H__
