@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,62 +23,62 @@
 
 #include "gnome-cmd-pixmap.h"
 
-G_BEGIN_DECLS
-
 /**
  * If you add a pixmap id here be sure to add its filename in
  * the array in imageloader.c
  */
-typedef enum {
+enum Pixmap
+{
     PIXMAP_NONE,
 
     PIXMAP_FLIST_ARROW_UP,
     PIXMAP_FLIST_ARROW_DOWN,
     PIXMAP_FLIST_ARROW_BLANK,
 
-    PIXMAP_SERVER_SMALL,
     PIXMAP_LOGO,
-    PIXMAP_EXEC,
     PIXMAP_EXEC_WHEEL,
-    PIXMAP_MKDIR,
-    PIXMAP_LOCK,
-    PIXMAP_HOME,
-    PIXMAP_DESKTOP,
-    PIXMAP_SMB_NETWORK,
-    PIXMAP_SMB_COMPUTER,
     PIXMAP_BOOKMARK,
 
     PIXMAP_OVERLAY_SYMLINK,
     PIXMAP_OVERLAY_UMOUNT,
-    PIXMAP_PARENT_DIR,
-    PIXMAP_ROOT_DIR,
-    PIXMAP_FTP_CONNECT,
-    PIXMAP_FTP_DISCONNECT,
     PIXMAP_SWITCH_V,
     PIXMAP_SWITCH_H,
 
     PIXMAP_INTERNAL_VIEWER,
 
     NUM_PIXMAPS
-} Pixmap;
+};
 
 
-void IMAGE_init (void);
-void IMAGE_free (void);
+void IMAGE_init ();
+void IMAGE_free ();
 
-GdkPixmap *IMAGE_get_pixmap (Pixmap pixmap_id);
-GdkBitmap *IMAGE_get_mask (Pixmap pixmap_id);
-GdkPixbuf *IMAGE_get_pixbuf (Pixmap pixmap_id);
 GnomeCmdPixmap *IMAGE_get_gnome_cmd_pixmap (Pixmap pixmap_id);
 
+inline GdkPixmap *IMAGE_get_pixmap (Pixmap pixmap_id)
+{
+    GnomeCmdPixmap *pixmap = IMAGE_get_gnome_cmd_pixmap (pixmap_id);
+    return pixmap ? pixmap->pixmap : NULL;
+}
+
+inline GdkBitmap *IMAGE_get_mask (Pixmap pixmap_id)
+{
+    GnomeCmdPixmap *pixmap = IMAGE_get_gnome_cmd_pixmap (pixmap_id);
+    return pixmap ? pixmap->mask : NULL;
+}
+
+inline GdkPixbuf *IMAGE_get_pixbuf (Pixmap pixmap_id)
+{
+    GnomeCmdPixmap *pixmap = IMAGE_get_gnome_cmd_pixmap (pixmap_id);
+    return pixmap ? pixmap->pixbuf : NULL;
+}
+
 gboolean IMAGE_get_pixmap_and_mask (GnomeVFSFileType type,
                                     const gchar *mime_type,
                                     gboolean symlink,
                                     GdkPixmap **pixmap,
                                     GdkBitmap **mask);
 
-void IMAGE_clear_mime_cache (void);
-
-G_END_DECLS
+void IMAGE_clear_mime_cache ();
 
 #endif // __IMAGELOADER_H__
