@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,7 +24,8 @@
 #include "gnome-cmd-file.h"
 
 void gcmd_tags_taglib_init();
-void gcmd_tags_taglib_shutdown();
-void gcmd_tags_taglib_load_metadata(GnomeCmdFile *finfo);
+inline void gcmd_tags_taglib_shutdown()     {}
+
+void gcmd_tags_taglib_load_metadata(GnomeCmdFile *f);
 
 #endif // __GNOME_CMD_TAGS_TAGLIB_H__
